@@ -30,7 +30,7 @@ import Data.Word
 
 import Data.UUID.Internal
 import qualified Data.UUID.Named as Shared
-import qualified Data.Digest.SHA1 as SHA1
+import qualified Crypto.Hash.SHA1 as SHA1
 
 
 -- |Generate a 'UUID' within the specified namespace out of the given
@@ -41,7 +41,5 @@ import qualified Data.Digest.SHA1 as SHA1
 generateNamed :: UUID    -- ^Namespace
               -> [Word8] -- ^Object
               -> UUID
-generateNamed = Shared.generateNamed hash 5
- where hash bytes
-           = case SHA1.hash bytes of
-               SHA1.Word160 w1 w2 w3 w4 _w5 -> (w1, w2, w3, w4)
+generateNamed = Shared.generateNamed SHA1.hash 5
+
